# PyFunction
Useful Python functions.

[![GitHub](https://img.shields.io/github/license/jzhang-github/PyFunction)](https://github.com/jzhang-github/PyFunction/blob/main/LICENSE)
[![Pypi](https://img.shields.io/pypi/v/zjpf.svg)](https://pypi.org/project/zjpf/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/zjpf)](https://pypi.org/project/zjpf/)
[![PyPI - Wheel](https://img.shields.io/pypi/wheel/zjpf)](https://pypi.org/project/zjpf/)

## PyPi
**Z**HANG **J**un **P**ython **f**unctions ([zjpf](https://pypi.org/project/zjpf/)).

## Install
```console
pip install zjpf
```

## Install from the source (latest version)
- Download the source code: [download](https://github.com/jzhang-github/PyFunction/archive/refs/heads/main.zip)
- Unzip `PyFunction-main.zip`  
- ```console
   pip install .
   ```

## Use this repo
```python
import zjpf as pf
print(dir(pf))
```

- **This is not a user-oriented software package (personal use only), contact ZHANG Jun if you want to know how to use this repo**

- **该项目不面向用户，仅供开发者个人使用。若您想了解本项目功能和用法，可联系张俊。**

